# Integrations

The Space Robotics Bench features a number of integrations that simplify common workflows. This section provides an overview of the design with further references for the specific instructions.

- [Integration with ROS 2](./ros2.md)
